@@ -45,7 +45,7 @@ Player::Player(qreal p_x, qreal p_y, const QString& p_playerID, const PlayerSett
     
     m_badBonusCountdownTimer = new QTimer;
     m_badBonusCountdownTimer->setInterval(badBonusTimerTimeout);
-    m_badBonusMillisecondsElapsed = 0;
+    m_badBonusMillisecondsToElapse = 0;
     connect(m_badBonusCountdownTimer, SIGNAL(timeout()), this, SLOT(slot_badBonusTimerTimeout()));
     
     resurrect();
@@ -91,6 +91,19 @@ void Player::init()
     m_arena->setCellElement(row, column, this);
 }
 
+void Player::pause()
+{
+    m_badBonusCountdownTimer->stop();
+}
+
+void Player::resume()
+{
+    if(m_badBonusMillisecondsToElapse > 0)
+    {
+        m_badBonusCountdownTimer->start();
+    }
+}
+
 void Player::goUp()
 {
     m_askedXSpeed = 0;
@@ -563,6 +576,7 @@ void Player::addBonus(Bonus* p_bonus)
                 m_askedYSpeed = askedYSpeedTemp;
                 
                 m_badBonusType = Granatier::Bonus::HYPERACTIVE;
+                m_badBonusMillisecondsToElapse = badBonusCountdown;
                 m_badBonusCountdownTimer->start();
             }
             break;
@@ -579,6 +593,7 @@ void Player::addBonus(Bonus* p_bonus)
                 m_askedYSpeed = askedYSpeedTemp;
                 
                 m_badBonusType = Granatier::Bonus::SLOW;
+                m_badBonusMillisecondsToElapse = badBonusCountdown;
                 m_badBonusCountdownTimer->start();
             }
             break;
@@ -616,17 +631,20 @@ void Player::addBonus(Bonus* p_bonus)
                 
                 m_moveMirrored = true;
                 m_badBonusType = Granatier::Bonus::MIRROR;
+                m_badBonusMillisecondsToElapse = badBonusCountdown;
                 m_badBonusCountdownTimer->start();
             }
             break;
         case Granatier::Bonus::SCATTY:
             m_badBonusType = Granatier::Bonus::SCATTY;
+            m_badBonusMillisecondsToElapse = badBonusCountdown;
             m_badBonusCountdownTimer->start();
             break;
         case Granatier::Bonus::RESTRAIN:
             m_normalBombArmory = m_bombArmory;
             m_bombArmory = 0;
             m_badBonusType = Granatier::Bonus::RESTRAIN;
+            m_badBonusMillisecondsToElapse = badBonusCountdown;
             m_badBonusCountdownTimer->start();
             break;
         case Granatier::Bonus::RESURRECT:
@@ -693,7 +711,7 @@ void Player::die()
     if(!m_death)
     {
         m_death = true;
-        emit dying(this);
+        emit dying();
         m_xSpeed = 0;
         m_xSpeed = 0;
         
@@ -715,6 +733,11 @@ bool Player::isAlive() const
 
 void Player::resurrect()
 {
+    if(m_badBonusMillisecondsToElapse > 0)
+    {
+        slot_removeBadBonus();
+    }
+    
     m_onIce = false;
     m_falling = false;
     m_death = false;
@@ -816,22 +839,21 @@ void Player::slot_refillBombArmory()
 
 void Player::slot_badBonusTimerTimeout()
 {
-    m_badBonusMillisecondsElapsed += badBonusTimerTimeout;
-    if(m_badBonusMillisecondsElapsed >= badBonusCountdown)
+    m_badBonusMillisecondsToElapse -= badBonusTimerTimeout;
+    if(m_badBonusMillisecondsToElapse <= 0)
     {
-        m_badBonusCountdownTimer->stop();
         slot_removeBadBonus();
     }
     else
     {
-        bonusUpdated(this, m_badBonusType, m_badBonusMillisecondsElapsed/(badBonusCountdown / 100));
+        bonusUpdated(this, m_badBonusType, (badBonusCountdown - m_badBonusMillisecondsToElapse)/(badBonusCountdown/100.));
     }
 }
 
 void Player::slot_removeBadBonus()
 {
     m_badBonusCountdownTimer->stop();
-    m_badBonusMillisecondsElapsed = 0;
+    m_badBonusMillisecondsToElapse = 0;
     
     switch (m_badBonusType)
     {
