@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 1995 Paul Olav Tvete <paul@troll.no>
  * Copyright (C) 2000-2009 Stephan Kulow <coolo@kde.org>
- * Copyright (C) 2010 Parker Coates <parker.coates@kdemail.net>
+ * Copyright (C) 2010 Parker Coates <coates@kde.org>
  *
  * License of original code:
  * -------------------------------------------------------------------------
@@ -43,6 +43,12 @@
 #include <KLocale>
 
 
+Idiot::Idiot( const DealerInfo * di )
+  : DealerScene( di )
+{
+}
+
+
 void Idiot::initialize()
 {
     setSceneAlignment( AlignHCenter | AlignVCenter );
@@ -56,6 +62,7 @@ void Idiot::initialize()
     talon->setSpread(0, 0);
     talon->setKeyboardSelectHint( KCardPile::NeverFocus );
     talon->setKeyboardDropHint( KCardPile::NeverFocus );
+    connect( talon, SIGNAL(clicked(KCard*)), this, SLOT(newCards()) );
 
     const qreal distx = 1.1;
 
@@ -79,7 +86,7 @@ void Idiot::initialize()
     m_away->setKeyboardSelectHint(KCardPile::NeverFocus);
     m_away->setKeyboardDropHint(KCardPile::ForceFocusTop);
 
-    connect( this, SIGNAL(cardClicked(KCard*)), this, SLOT(handleCardClick(KCard*)) );
+    connect( this, SIGNAL(cardClicked(KCard*)), this, SLOT(tryAutomaticMove(KCard*)) );
 
     setActions(DealerScene::Hint | DealerScene::Demo | DealerScene::Deal);
     setSolver( new IdiotSolver(this ) );
@@ -112,7 +119,7 @@ bool Idiot::checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const
     switch ( pile->pileRole() )
     {
     case PatPile::Foundation:
-        return canMoveAway( newCards.first() );
+        return true;
     case PatPile::Tableau:
         return oldCards.isEmpty() && newCards.size() == 1;
     case PatPile::Stock:
@@ -134,11 +141,9 @@ bool Idiot::checkRemove(const PatPile * pile, const QList<KCard*> & cards) const
 
 bool Idiot::canMoveAway(const KCard * card) const
 {
-    if ( card->pile() == talon || card->pile() == m_away )
-        return false;
-
-    if ( card != card->pile()->topCard() )
-        return false;
+    Q_ASSERT( card->pile() != talon );
+    Q_ASSERT( card->pile() != m_away );
+    Q_ASSERT( card == card->pile()->topCard() );
 
     for ( int i = 0; i < 4; ++i )
     {
@@ -157,30 +162,37 @@ bool Idiot::canMoveAway(const KCard * card) const
 
 
 
-void Idiot::handleCardClick( KCard * card )
+bool Idiot::tryAutomaticMove( KCard * card )
 {
-    // Only the top card of a pile can be clicked.
-    if ( card != card->pile()->topCard())
-        return;
+    if ( !isCardAnimationRunning()
+         && card
+         && card->pile()
+         && card == card->pile()->topCard()
+         && card->pile() != talon
+         && card->pile() != m_away )
+    {
+        KCardPile * destination = 0;
+        if ( canMoveAway( card ) )
+            destination = m_away;
+        else if ( m_play[0]->isEmpty() )
+            destination = m_play[0];
+        else if ( m_play[1]->isEmpty() )
+            destination = m_play[1];
+        else if ( m_play[2]->isEmpty() )
+            destination = m_play[2];
+        else if ( m_play[3]->isEmpty() )
+            destination = m_play[3];
 
-    KCardPile * destination = 0;
-    if ( card->pile() == talon )
-        drawDealRowOrRedeal();
-    else if ( canMoveAway( card) )
-        destination = m_away;
-    else if ( m_play[0]->isEmpty() )
-        destination = m_play[0];
-    else if ( m_play[1]->isEmpty() )
-        destination = m_play[1];
-    else if ( m_play[2]->isEmpty() )
-        destination = m_play[2];
-    else if ( m_play[3]->isEmpty() )
-        destination = m_play[3];
-
-    if ( destination )
-        moveCardToPile( card, destination, DURATION_MOVE );
+        if ( destination )
+        {
+            moveCardToPile( card, destination, DURATION_MOVE );
+            return true;
+        }
+    }
+    return false;
 }
 
+
 // The game is won when:
 //  1. all cards are dealt.
 //  2. all piles contain exactly one ace.
@@ -249,7 +261,7 @@ public:
 
     virtual DealerScene *createGame() const
     {
-        return new Idiot();
+        return new Idiot( this );
     }
 } idiotDealerInfo;
 
